
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { useAuth } from "@/contexts/auth/AuthContext";
import { ArrowRight, Zap } from "lucide-react";
import { useState, useEffect, lazy, Suspense } from "react";
import { useNavigate } from "react-router-dom";
import { Image } from "@/components/ui/image";
import TutorialDialog from "./TutorialDialog";

// Lazily load the authentication overlay to improve initial load time
const AuthOverlay = lazy(() => import("@/components/auth/AuthOverlay").then(mod => ({ default: mod.AuthOverlay })));

// Predefine features for faster initial render
const FEATURES = [
  "World's First AI Pest Advisor",
  "Trained on Billions of Parameters",
  "90% more accurate than Google",
  "Eco-Friendly Solutions First"
];

const HeroSection = () => {
  const { isAuthenticated } = useAuth();
  const [query, setQuery] = useState("");
  const navigate = useNavigate();
  const [activeFeature, setActiveFeature] = useState(0);
  const [showAuthOverlay, setShowAuthOverlay] = useState(false);
  const [isHeadingVisible, setIsHeadingVisible] = useState(true);
  const [isInputVisible, setIsInputVisible] = useState(false);
  const [isTaglineVisible, setIsTaglineVisible] = useState(false);

  // Progressive loading of UI elements for better perceived performance
  useEffect(() => {
    // Immediate visibility for heading
    setIsHeadingVisible(true);
    
    // Delayed visibility for other elements to prioritize critical content first
    const inputTimer = setTimeout(() => setIsInputVisible(true), 100);
    const taglineTimer = setTimeout(() => setIsTaglineVisible(true), 200);
    
    // Start feature rotation with a significant delay for mobile
    const rotationTimer = setTimeout(() => {
      const interval = setInterval(() => {
        setActiveFeature((prev) => (prev + 1) % FEATURES.length);
      }, 3000);
      
      return () => clearInterval(interval);
    }, 5000); // Increased delay to 5000ms on mobile for better performance
    
    return () => {
      clearTimeout(inputTimer);
      clearTimeout(taglineTimer);
      clearTimeout(rotationTimer);
    };
  }, []);

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    
    if (query.trim()) {
      if (isAuthenticated) {
        navigate("/chat", { state: { initialQuery: query, newThread: true } });
      } else {
        setShowAuthOverlay(true);
      }
    }
  };

  const handleCloseAuthOverlay = () => {
    setShowAuthOverlay(false);
  };

  return (
    <section className="bg-gradient-to-b from-white to-pestg-lightgray py-8 md:py-24">
      <div className="pestg-container">
        <div className="flex flex-col items-center text-center mb-6 md:mb-12">
          {isHeadingVisible && (
            <h1 className="text-2xl md:text-6xl font-bold leading-tight mb-3 md:mb-6 animate-fade-in">
              <span className="text-pestg-green">Pest</span>
              <span className="text-pestg-blue">Guard</span>
              <span className="text-gray-800"> AI</span>
              <span className="block mt-1 md:mt-2 text-xl md:text-4xl">Your 100% free AI Pest Control consultant</span>
            </h1>
          )}
          
          <div className="h-10 md:h-16 flex items-center justify-center mb-3 md:mb-6">
            {FEATURES.map((feature, index) => (
              <p 
                key={index}
                className={`text-base md:text-2xl font-medium absolute transition-opacity duration-300 ${
                  index === activeFeature
                    ? "opacity-100 transform-none" 
                    : "opacity-0"
                }`}
                aria-hidden={index !== activeFeature}
              >
                <span className="bg-gradient-to-r from-pestg-green to-pestg-blue bg-clip-text text-transparent">
                  {feature}
                </span>
              </p>
            ))}
          </div>
          
          {isTaglineVisible && (
            <p className="text-sm md:text-xl text-gray-700 max-w-3xl mx-auto mb-5 md:mb-8 animate-fade-in">
              Get instant answers from our advanced AI trained on billions of pest management parameters, prioritizing eco-friendly solutions.
            </p>
          )}
        </div>
        
        {isInputVisible && (
          <div className="max-w-3xl mx-auto animate-fade-in">
            <form onSubmit={handleSubmit} className="bg-white p-2 md:p-3 rounded-full shadow-lg border border-gray-100">
              <div className="relative">
                <Input 
                  placeholder="Describe your pest problem..." 
                  className="pl-4 pr-14 py-3 md:py-6 text-base md:text-xl rounded-full border-0 shadow-none"
                  value={query}
                  onChange={(e) => setQuery(e.target.value)}
                />
                <Button 
                  type="submit" 
                  size="lg" 
                  className="absolute right-1 top-1/2 transform -translate-y-1/2 rounded-full h-10 w-10 md:h-12 md:w-12 p-0 touch-target"
                >
                  <ArrowRight className="h-4 w-4 md:h-5 md:w-5" />
                </Button>
              </div>
            </form>
            
            <div className="flex justify-center mt-3 md:mt-6">
              <div className="bg-white/80 backdrop-blur-sm rounded-full px-3 md:px-6 py-2 md:py-3 inline-flex items-center shadow-sm">
                <Zap className="h-4 w-4 md:h-5 md:w-5 text-yellow-500 mr-2" />
                <p className="text-xs md:text-base text-gray-700">
                  AI-powered responses in seconds, not minutes!
                </p>
              </div>
            </div>
            
            <div className="flex justify-center mt-4">
              <TutorialDialog className="shadow-sm" />
            </div>
          </div>
        )}

        {/* Auth Overlay - Only render when needed, using Suspense for code splitting */}
        {showAuthOverlay && (
          <Suspense fallback={<div className="fixed inset-0 bg-black/20 z-50"></div>}>
            <AuthOverlay 
              isOpen={showAuthOverlay} 
              onClose={handleCloseAuthOverlay} 
              initialQuery={query}
            />
          </Suspense>
        )}
      </div>
    </section>
  );
};

export default HeroSection;
